
# General

* Use Preferences.jl to manage settings/default for this pkg
    * See: https://github.com/JuliaPackaging/Preferences.jl
    * Note: add a .gitignore for LocalPreferences.toml
* (?) we *could* use Artifact for templates data etc... but it seems overkill

# Pkg Creation

* take a set of packages (i.e. an initial env) and add them to the project
  (if public registry, also add the [compat] entry so the initial registration succeed)
  (maybe also for others registry ? this is good practice)
* Use the PkgTemplates option to `dev` the newly created packages
* Add an option "minimal=true" to remove all the examples/docs we have in [README, src/Pkg.jl, test/runtests.jl]
* (?) redirect output when creating the packages with PkgTemplates to remove all
the message generated by Pkg. Only keep errors if any (should not be possible to error here, if we
add the external package ourself)
* Use LibSSH2_jll to help generate the keys for: doc-repo access token, git hub access itself ?.
Note: we cannot easiuly use the open ssh install by GitForWindows because it does NOT ouput cleanly to stdout !
* If we can get access to the GitHub api... well... we could do a LOT!

# Some old notes that were in the README.md template

```
Some note to clean-up
* The Badge Doc:Stable will link to 404 until you have published at last one release (right column)
* The Badge Doc:Dev link to 404 until you have run it MANUALLY 
    * Todo add comments in Documenter.yml to enable on main commit (but explain that it cost minutes...)
    * In the doc setup, provite link to e.g. https://github.com/ylvain/Pk2.jl/actions/workflows/Documenter.yml
    * Run the doc manully to check deployment...
    * Explain that once deployed, the doc still need to be published by GitHub to the github.io site (wait or go see in the https://github.com/ylvain/PkDoc/deployments if it is publised)
* The Tests and Coverage run for each commit on `main`, for each pull request to `main` and can also be run manually
* The documentation has "Edit on GitHub" that links to https://github.com/ylvain/Pk2.jl/blob/master/docs/src/index.md#. master is not the correct branch... Links works but only because GitHub redirect to main
* Add some lines of codes in /src and some testset in /runtests, allows to check better doc and coverage
* If deploy doc to SAME repo, but as section telling how to enable GitPages on gh-pages (only after first run of documentation otherwise the bransh gh-pages is not yet created)
```

# SSH - cannot do the easy way like GitTools on Windows

* Using the execute function in GitTools we have
```julia
ulia> execute(`ssh -V`)
←[0m←[0m(stdout = "", stderr = "OpenSSH_8.5p1, OpenSSL 1.1.1k  25 Mar 2021\n", code = 0)
julia> execute(`ssh -T git@github.com`)
←[0m←[0m(stdout = "", stderr = "", code = 1)
julia>
```
* But the last command do actually ouput !
```bash
Yoann@IronSunrise MINGW64 /c/Sources/julia/tmp/Pk2 (main)
$ ssh -T git@github.com
Hi ylvain! You've successfully authenticated, but GitHub does not provide shell access.
```

# GutHub

* When we do the initial push to the repo, GitHub does NOT create all the Actions from
the workflow files... it's a bug on their side (touching the .yml files and commit will
create the Actions). Seems related to the fact that the Tests workflow start running
immediatly...

# General Registry

REQUIRED to register in the public General registry
- The URL repo MUST end with ".jl"
- All dependencies in Project.toml MUST have an upper-bounded [compat] entry
  ==> The CompatHelper workflow ensure that. Should be blocking check before
- There MUST be a LICENSE file in the toplevel package, it must be OSI approved
- Follow the package naming guiline: https://julialang.github.io/Pkg.jl/dev/creating-packages/#Package-naming-guidelines-1
- The public package may be hosted/cloned on others julia servers, the doc will be build by docs/make.jl
  ==> The doc should be setup to deploy locally

Using Registrator.jl to register in the General registry
https://juliaregistries.github.io/Registrator.jl/stable/webui/#Usage-(For-Package-Maintainers)-1
Go the registry Bot page: https://github.com/JuliaRegistries/Registrator.jl
Click the Install app: https://github.com/apps/juliateam-registrator/installations/new/permissions?target_id=77893098
This install the bot to All or Selected repo
The manual procedure is then:
  0 Run CompatHelper to check [compact]
  1 Set the Project.toml version to version that must be registered
    Do NOT create a Tag/Release yet for the commit of the version to be registered (may fail)
  2 Comment `@JuliaRegistrator register` on the commit/branch you want to register
  3 If something is incorrect, adjust, and redo
  4 The bot will comment giving the git command to add a version Tag to commit being registered, e.g.
    - git tag -a v0.1.0 -m "<description of version>" e7f59bec82a47801360f80caa1bf3c5ff058c157
    - git push v0.1.0
  5 If the registration is merged, then execute the git commands to tag it


  TagBot:                  [4+5] used to perform the tagging/release after successful registration
  julia-actions/Register:  [1+2] simply bump the version and add the `@JuliaRegistrator register` to the commit 


# Documenter

* The links to `stable` and `dev` are always active trough the Badges,
il would be nice to push a page saying that the doc is not yet generated
and what action will generate it. Now it 404.
* find a way to change the color of symbol `code` in dark theme (dark red is not nice)
* add a kind static-site pregen (use Mustache.jl like PkgTemplate), purpose
    * allows to cross links between packages doc using [mylink]({{OtherPkg}}base-permalink)
    * probably a lot of others usefull things
* documente the workflow to generate/test the doc locally efficiently
    ```
    $ cd dir-of-the-package
    $ jl --project=.               [important: jl is the alias that use Revise, needed for docstrings update]
    julia> include("docs/makejl")
    ```
    * Keep the julia session open, re-run `include("docs/makejl")` to re-generate
    * open the local doc from "docs/build/index.html"
    * TODO: doing local generate, we will not deploy. Need to detect this.
    then simply output a link to the index.html file. For a VsCode terminal
    one can directly click on it... (or `run` it under windows to open it in brower)

# SysImage

* TODO